# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global section		devel
%global upstreamrel	1200
%global upstreamver	9.4-%{upstreamrel}

Summary:	JDBC driver for PostgreSQL
Name:		postgresql-jdbc
Version:	9.4.%{upstreamrel}
Release:	%mkrel 1
Group:          Development/Java
# ASL 2.0 applies only to postgresql-jdbc.pom file, the rest is BSD
License:	BSD and ASL 2.0
URL:		http://jdbc.postgresql.org/

Source0:	http://jdbc.postgresql.org/download/%{name}-%{upstreamver}.src.tar.gz
# originally http://repo2.maven.org/maven2/postgresql/postgresql/8.4-701.jdbc4/postgresql-8.4-701.jdbc4.pom:
Source1:	%{name}.pom

# Revert back fix for travis build which breaks our ant-build for version 1.9.2
# & 1.9.4.
# ~> downstream
# ~> 1118667
Patch0:		postgresql-jdbc-9.3-1102-revert-88b9a034.patch

BuildArch:	noarch
BuildRequires:	java-devel >= 1:1.8
BuildRequires:	jpackage-utils
BuildRequires:	ant
BuildRequires:	ant-junit
BuildRequires:	junit
# gettext is only needed if we try to update translations
#BuildRequires:	gettext
Requires:	jpackage-utils
Requires:	java-headless >= 1:1.8

%description
PostgreSQL is an advanced Object-Relational database management
system. The postgresql-jdbc package includes the .jar files needed for
Java programs to access a PostgreSQL database.

%package javadoc
Summary:        API docs for %{name}
Group:          Documentation

%description javadoc
This package contains the API Documentation for %{name}.

%prep
%setup -c -q
mv -f %{name}-%{upstreamver}.src/* .
rm -f %{name}-%{upstreamver}.src/.gitignore
rm -f %{name}-%{upstreamver}.src/.travis.yml
rmdir %{name}-%{upstreamver}.src

# remove any binary libs
find -name "*.jar" -or -name "*.class" | xargs rm -f

%patch0 -p1 -b .revert-travis-fix

%build
export OPT_JAR_LIST="ant/ant-junit junit"
export CLASSPATH=

# Ideally we would run "sh update-translations.sh" here, but that results
# in inserting the build timestamp into the generated messages_*.class
# files, which makes rpmdiff complain about multilib conflicts if the
# different platforms don't build in the same minute.  For now, rely on
# upstream to have updated the translations files before packaging.

ant jar publicapi

%install
install -d $RPM_BUILD_ROOT%{_javadir}
# Per jpp conventions, jars have version-numbered names and we add
# versionless symlinks.
install -m 644 jars/postgresql-%{upstreamver}.jdbc41.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar


pushd $RPM_BUILD_ROOT%{_javadir}
# Also, for backwards compatibility with our old postgresql-jdbc packages,
# add these symlinks.  (Probably only the jdbc3 symlink really makes sense?)
ln -s postgresql-jdbc.jar postgresql-jdbc2.jar
ln -s postgresql-jdbc.jar postgresql-jdbc2ee.jar
ln -s postgresql-jdbc.jar postgresql-jdbc3.jar
popd

# Install the pom after inserting the correct version number
sed 's/UPSTREAM_VERSION/%{upstreamver}/g' %{SOURCE1} >JPP-%{name}.pom
install -d -m 755 $RPM_BUILD_ROOT%{_mavenpomdir}/
install -m 644 JPP-%{name}.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap

install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}
cp -ra build/publicapi $RPM_BUILD_ROOT%{_javadocdir}/%{name}
install -d build/publicapi docs/%{name}


%check
%if 0%{?runselftest}
# Note that this requires to have PostgreSQL properly configured;  for this
# reason the testsuite is turned off by default (see org/postgresql/test/README)
test_log=test.log
# TODO: more reliable testing
ant test 2>&1 | tee "$test_log" || :
( test -f "$test_log" && ! grep FAILED "$test_log" )

%endif


%files -f .mfiles
%doc LICENSE README.md doc/*
%{_javadir}/%{name}2.jar
%{_javadir}/%{name}2ee.jar
%{_javadir}/%{name}3.jar

%files javadoc
%doc LICENSE
%doc %{_javadocdir}/%{name}




%changelog
* Fri Feb 13 2015 luigiwalser <luigiwalser> 9.4.1200-1.mga5
+ Revision: 814848
- 9.4.1200 (sync with f22)

* Fri Dec 26 2014 dmorgan <dmorgan> 9.3.1102-6.mga5
+ Revision: 806238
- Sync with fc21

* Sat Nov 08 2014 cjw <cjw> 0:9.3.1102-5.mga5
+ Revision: 796065
- remove the maven-metadata xml file because it breaks the build

  + tv <tv>
    - adjust file list
    - Drop no longer needed BuildRequires on java-rpmbuild

* Wed Oct 15 2014 umeabot <umeabot> 0:9.3.1102-4.mga5
+ Revision: 741572
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:9.3.1102-3.mga5
+ Revision: 687735
- Mageia 5 Mass Rebuild

* Wed Aug 27 2014 tv <tv> 0:9.3.1102-2.mga5
+ Revision: 668640
- requires java-headless instead of java-headless (so that LO pull less

* Fri Jul 18 2014 luigiwalser <luigiwalser> 0:9.3.1102-1.mga5
+ Revision: 653558
- 9.3.1102
- add patch from fedora to fix build

* Sun Apr 27 2014 luigiwalser <luigiwalser> 0:9.3.1101-1.mga5
+ Revision: 618341
- 9.3.1101

* Fri Nov 08 2013 dmorgan <dmorgan> 0:9.2.1002-6.mga4
+ Revision: 550000
- Remove useless macros

* Sat Oct 19 2013 umeabot <umeabot> 0:9.2.1002-5.mga4
+ Revision: 531318
- Mageia 4 Mass Rebuild

* Sat Aug 03 2013 joequant <joequant> 0:9.2.1002-4.mga4
+ Revision: 462958
- remove ant-nodeps and ant-trax

* Sun Apr 14 2013 dmorgan <dmorgan> 0:9.2.1002-3.mga3
+ Revision: 410103
- Add require on jpackage-utils ( mga#9645)

* Fri Feb 08 2013 fwang <fwang> 0:9.2.1002-2.mga3
+ Revision: 395328
- cleanup spec

* Fri Feb 08 2013 fwang <fwang> 0:9.2.1002-1.mga3
+ Revision: 395322
- new version 9.2-1002

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Aug 12 2011 dmorgan <dmorgan> 0:9.0.801-1.mga2
+ Revision: 132810
- Clean spec file

  + gil <gil>
    - update to 9.0-801

* Fri Jan 28 2011 dmorgan <dmorgan> 0:8.3.603-2.0.2.mga1
+ Revision: 43103
- imported package postgresql-jdbc


* Fri Sep 04 2009 Thierry Vignaud <tvignaud@mandriva.com> 0:8.3.603-2.0.2mdv2010.0
+ Revision: 430767
- rebuild

* Fri Aug 08 2008 Thierry Vignaud <tvignaud@mandriva.com> 0:8.3.603-2.0.1mdv2009.0
+ Revision: 269010
- rebuild early 2009.0 package (before pixel changes)

* Thu Jun 05 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:8.3.603-0.0.1mdv2009.0
+ Revision: 215217
- new version 8.3-603

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Tue Nov 27 2007 Alexander Kurtakov <akurtakov@mandriva.org> 0:8.2.504-2mdv2008.1
+ Revision: 113387
- fix java 5 build

  + Anssi Hannula <anssi@mandriva.org>
    - remove unnecessary Requires(post) on java-gcj-compat


* Fri Jan 12 2007 David Walluck <walluck@mandriva.org> 8.2.504-1mdv2007.0
+ Revision: 108100
- 8.2.504
- Import postgresql-jdbc

* Fri Sep 01 2006 David Walluck <walluck@mandriva.org> 0:8.1.407-2mdv2007.0
- add xalan-j2-serializer to OPT_JAR_LIST

* Mon Jun 05 2006 David Walluck <walluck@mandriva.org> 0:8.1.407-1mdv2007.0
- 8.1-407
- rebuild for libgcj.so.7

* Wed Jan 18 2006 David Walluck <walluck@mandriva.org> 0:8.1.404-2mdk
- fix building of docs

* Mon Jan 02 2006 David Walluck <walluck@mandriva.org> 0:8.1.404-1mdk
- release
- build documentation
- spec cleanup

* Wed Feb 02 2005 Jason Corley <jason.corley@gmail.com> 0:8.0.309-2jpp
- Name changed to postgresql-jdbc

* Wed Feb 02 2005 Jason Corley <jason.corley@gmail.com> 0:8.0.309-1jpp
- Initial creation

